==> zio-aws-networkfirewall_2.13-5.17.162.3-sources.jar: zio/aws/networkfirewall/model/CreateRuleGroupRequest.scala <==
package zio.aws.networkfirewall.model
import zio.aws.networkfirewall.model.primitives.{
  RuleCapacity,
  Description,
  RulesString,
  ResourceName
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateRuleGroupRequest(
    ruleGroupName: ResourceName,
    ruleGroup: Optional[zio.aws.networkfirewall.model.RuleGroup] =
      Optional.Absent,
    rules: Optional[RulesString] = Optional.Absent,
    `type`: zio.aws.networkfirewall.model.RuleGroupType,
    description: Optional[Description] = Optional.Absent,
    capacity: RuleCapacity,
    tags: Optional[Iterable[zio.aws.networkfirewall.model.Tag]] =
      Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest = {
    import CreateRuleGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
      .builder()
      .ruleGroupName(ResourceName.unwrap(ruleGroupName): java.lang.String)
      .optionallyWith(ruleGroup.map(value => value.buildAwsValue()))(
        _.ruleGroup
      )
      .optionallyWith(
        rules.map(value => RulesString.unwrap(value): java.lang.String)
      )(_.rules)
      .`type`(`type`.unwrap)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .capacity(RuleCapacity.unwrap(capacity): Integer)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.networkfirewall.model.CreateRuleGroupRequest.ReadOnly =
    zio.aws.networkfirewall.model.CreateRuleGroupRequest.wrap(buildAwsValue())
}
object CreateRuleGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkfirewall.model.CreateRuleGroupRequest =
      zio.aws.networkfirewall.model.CreateRuleGroupRequest(
        ruleGroupName,
        ruleGroup.map(value => value.asEditable),
        rules.map(value => value),
        `type`,
        description.map(value => value),
        capacity,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dryRun.map(value => value)
      )
    def ruleGroupName: ResourceName
    def ruleGroup: Optional[zio.aws.networkfirewall.model.RuleGroup.ReadOnly]
    def rules: Optional[RulesString]
    def `type`: zio.aws.networkfirewall.model.RuleGroupType
    def description: Optional[Description]
    def capacity: RuleCapacity
    def tags: Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]]
    def dryRun: Optional[Boolean]
    def getRuleGroupName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(ruleGroupName)
    def getRuleGroup
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.RuleGroup.ReadOnly] =
      AwsError.unwrapOptionField("ruleGroup", ruleGroup)
    def getRules: ZIO[Any, AwsError, RulesString] =
      AwsError.unwrapOptionField("rules", rules)
    def getType
        : ZIO[Any, Nothing, zio.aws.networkfirewall.model.RuleGroupType] =
      ZIO.succeed(`type`)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getCapacity: ZIO[Any, Nothing, RuleCapacity] = ZIO.succeed(capacity)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
  ) extends zio.aws.networkfirewall.model.CreateRuleGroupRequest.ReadOnly {
    override val ruleGroupName: ResourceName =
      zio.aws.networkfirewall.model.primitives
        .ResourceName(impl.ruleGroupName())
    override val ruleGroup
        : Optional[zio.aws.networkfirewall.model.RuleGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ruleGroup())
        .map(value => zio.aws.networkfirewall.model.RuleGroup.wrap(value))
    override val rules: Optional[RulesString] = zio.aws.core.internal
      .optionalFromNullable(impl.rules())
      .map(value => zio.aws.networkfirewall.model.primitives.RulesString(value))
    override val `type`: zio.aws.networkfirewall.model.RuleGroupType =
      zio.aws.networkfirewall.model.RuleGroupType.wrap(impl.`type`())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.networkfirewall.model.primitives.Description(value))
    override val capacity: RuleCapacity =
      zio.aws.networkfirewall.model.primitives.RuleCapacity(impl.capacity())
    override val tags
        : Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.networkfirewall.model.Tag.wrap(item)
          }.toList
        )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
  ): zio.aws.networkfirewall.model.CreateRuleGroupRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkfirewall_2.13-7.21.15.9-sources.jar: zio/aws/networkfirewall/model/CreateRuleGroupRequest.scala <==
package zio.aws.networkfirewall.model
import zio.aws.networkfirewall.model.primitives.{
  RuleCapacity,
  Description,
  RulesString,
  ResourceName
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class CreateRuleGroupRequest(
    ruleGroupName: ResourceName,
    ruleGroup: Optional[zio.aws.networkfirewall.model.RuleGroup] =
      Optional.Absent,
    rules: Optional[RulesString] = Optional.Absent,
    `type`: zio.aws.networkfirewall.model.RuleGroupType,
    description: Optional[Description] = Optional.Absent,
    capacity: RuleCapacity,
    tags: Optional[Iterable[zio.aws.networkfirewall.model.Tag]] =
      Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent,
    encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration
    ] = Optional.Absent,
    sourceMetadata: Optional[zio.aws.networkfirewall.model.SourceMetadata] =
      Optional.Absent,
    analyzeRuleGroup: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest = {
    import CreateRuleGroupRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
      .builder()
      .ruleGroupName(ResourceName.unwrap(ruleGroupName): java.lang.String)
      .optionallyWith(ruleGroup.map(value => value.buildAwsValue()))(
        _.ruleGroup
      )
      .optionallyWith(
        rules.map(value => RulesString.unwrap(value): java.lang.String)
      )(_.rules)
      .`type`(`type`.unwrap)
      .optionallyWith(
        description.map(value => Description.unwrap(value): java.lang.String)
      )(_.description)
      .capacity(RuleCapacity.unwrap(capacity): Integer)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(sourceMetadata.map(value => value.buildAwsValue()))(
        _.sourceMetadata
      )
      .optionallyWith(analyzeRuleGroup.map(value => value: java.lang.Boolean))(
        _.analyzeRuleGroup
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkfirewall.model.CreateRuleGroupRequest.ReadOnly =
    zio.aws.networkfirewall.model.CreateRuleGroupRequest.wrap(buildAwsValue())
}
object CreateRuleGroupRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkfirewall.model.CreateRuleGroupRequest =
      zio.aws.networkfirewall.model.CreateRuleGroupRequest(
        ruleGroupName,
        ruleGroup.map(value => value.asEditable),
        rules.map(value => value),
        `type`,
        description.map(value => value),
        capacity,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        dryRun.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        sourceMetadata.map(value => value.asEditable),
        analyzeRuleGroup.map(value => value)
      )
    def ruleGroupName: ResourceName
    def ruleGroup: Optional[zio.aws.networkfirewall.model.RuleGroup.ReadOnly]
    def rules: Optional[RulesString]
    def `type`: zio.aws.networkfirewall.model.RuleGroupType
    def description: Optional[Description]
    def capacity: RuleCapacity
    def tags: Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]]
    def dryRun: Optional[Boolean]
    def encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ]
    def sourceMetadata
        : Optional[zio.aws.networkfirewall.model.SourceMetadata.ReadOnly]
    def analyzeRuleGroup: Optional[Boolean]
    def getRuleGroupName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(ruleGroupName)
    def getRuleGroup
        : ZIO[Any, AwsError, zio.aws.networkfirewall.model.RuleGroup.ReadOnly] =
      AwsError.unwrapOptionField("ruleGroup", ruleGroup)
    def getRules: ZIO[Any, AwsError, RulesString] =
      AwsError.unwrapOptionField("rules", rules)
    def getType
        : ZIO[Any, Nothing, zio.aws.networkfirewall.model.RuleGroupType] =
      ZIO.succeed(`type`)
    def getDescription: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("description", description)
    def getCapacity: ZIO[Any, Nothing, RuleCapacity] = ZIO.succeed(capacity)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getSourceMetadata: ZIO[
      Any,
      AwsError,
      zio.aws.networkfirewall.model.SourceMetadata.ReadOnly
    ] = AwsError.unwrapOptionField("sourceMetadata", sourceMetadata)
    def getAnalyzeRuleGroup: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("analyzeRuleGroup", analyzeRuleGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
  ) extends zio.aws.networkfirewall.model.CreateRuleGroupRequest.ReadOnly {
    override val ruleGroupName: ResourceName =
      zio.aws.networkfirewall.model.primitives
        .ResourceName(impl.ruleGroupName())
    override val ruleGroup
        : Optional[zio.aws.networkfirewall.model.RuleGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ruleGroup())
        .map(value => zio.aws.networkfirewall.model.RuleGroup.wrap(value))
    override val rules: Optional[RulesString] = zio.aws.core.internal
      .optionalFromNullable(impl.rules())
      .map(value => zio.aws.networkfirewall.model.primitives.RulesString(value))
    override val `type`: zio.aws.networkfirewall.model.RuleGroupType =
      zio.aws.networkfirewall.model.RuleGroupType.wrap(impl.`type`())
    override val description: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => zio.aws.networkfirewall.model.primitives.Description(value))
    override val capacity: RuleCapacity =
      zio.aws.networkfirewall.model.primitives.RuleCapacity(impl.capacity())
    override val tags
        : Optional[List[zio.aws.networkfirewall.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.networkfirewall.model.Tag.wrap(item)
          }.toList
        )
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val encryptionConfiguration: Optional[
      zio.aws.networkfirewall.model.EncryptionConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.encryptionConfiguration())
      .map(value =>
        zio.aws.networkfirewall.model.EncryptionConfiguration.wrap(value)
      )
    override val sourceMetadata
        : Optional[zio.aws.networkfirewall.model.SourceMetadata.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceMetadata())
        .map(value => zio.aws.networkfirewall.model.SourceMetadata.wrap(value))
    override val analyzeRuleGroup: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.analyzeRuleGroup())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkfirewall.model.CreateRuleGroupRequest
  ): zio.aws.networkfirewall.model.CreateRuleGroupRequest.ReadOnly =
    new Wrapper(impl)
}
